
function table_tex(Data,font,row_heading,column_heading,nc,path_out,TextFile,caption)
% tex table
%---------------------------------------------------
% INPUT:
% Data = (nr x nc_total) matrix of numerical data displayed in table
%        with nc columns
% font = font format of the Data (e.g. font ='%8.6f')
% row_heading = nr vector of strings that are names of
%               displayed quantities
% column_heading = nc_total vector of strings that are names
%                  of variables which characteristics are displayed
% nc = number of columns (without the first "heading" column) in the table
% path_out = directory where the file with table is stored
% TextFile = name of the file identifier that is associated with the
%            output file
% caption = text for the caption of the table (string variable)
%---------------------------------------------------
% OUTPUT:
% - tex table stored a tex file associated with the file identifier 
%   TextFile and located in "path_out"
%---------------------------------------------------
%---------------------------------------------------
% **************************************************************
%  Tex table displaying characteristics of Data as listed in row_heading
%  in nc columns
% **************************************************************
clf 
[nr,nc_total]=size(Data);
nblocks_full=floor(nc_total/nc);
nc_rest=nc_total-nblocks_full*nc;

begin_tabular='\begin{tabular}{l|';
for i=1:nc
  begin_tabular=[begin_tabular 'c'];    
end  
begin_tabular=[begin_tabular '}'];

fprintf(TextFile,'\n');  
fprintf(TextFile,'\\begin{table}[!ht]\n');
fprintf(TextFile,'\\begin{center}\n');
fprintf(TextFile,'%s\n',begin_tabular);

for i=1:nblocks_full
  fprintf(TextFile,'\\hline\n');    
  head='& ';
  for j=1:nc-1
    head=[head deblank(column_heading((i-1)*nc+j,:)) ' & ']; 
  end
  head=[head deblank(column_heading(i*nc,:)) ' \\\\'];
  fprintf(TextFile,head);     
  fprintf(TextFile,'\\hline\n');    
  for ii=1:nr
    row=[deblank(row_heading(ii,:)) ' & ']; 
    for jj=1:nc-1
      row=[row num2str(Data(ii,(i-1)*nc+jj),font) ' & ']; 
    end
    row=[row num2str(Data(ii,i*nc),font) ' \\'];
    fprintf(TextFile, '%s\n', row);    
  end
  fprintf(TextFile,'\\hline\n');      
end   

if nblocks_full==0
  i=0;    
end    
if nc_rest>0
  fprintf(TextFile,'\\hline\n');    
  head='& ';
  for j=1:nc_rest
    head=[head deblank(column_heading(i*nc+j,:)) ' & ']; 
  end
  for j=1:nc-nc_rest-1
    head=[head ' &']; 
  end
  head=[head ' \\\\'];
  fprintf(TextFile,head);     
  fprintf(TextFile,'\\hline\n');    
  for ii=1:nr
    row=[deblank(row_heading(ii,:)) ' & ']; 
    for jj=1:nc_rest
      row=[row num2str(Data(ii,i*nc+jj),font) ' & ']; 
    end
    for jj=1:nc-nc_rest-1
      row=[row ' & ']; 
    end
    row=[row ' \\'];
    fprintf(TextFile,'%s\n', row);
  end    
  fprintf(TextFile,'\\hline\n');      
end    

fprintf(TextFile,'\\end{tabular}\n');
fprintf(TextFile,'\\caption{%s}\n', caption);
fprintf(TextFile,'\\end{center}\n');
fprintf(TextFile,'\\end{table}\n');

